@@ -14,7 +14,6 @@ except:
 
 class Alm(properties.Multipoled):
 
-
     name = None
 
     def __init__(self, **kwargs):
@@ -37,18 +36,22 @@ class Alm(properties.Multipoled):
 
     def smooth(self, smooth_window, **kwargs):
         smoothed_name = convert.tools.get_out_name(
-                out_name=kwargs.get('smoothed_name'),
-                suffix='alm_smoothed.fit'
-            )
+            out_name=kwargs.get('smoothed_name'),
+            suffix='alm_smoothed.fit'
+        )
         smoothed_name = convert.smooth_alm(
-                self.name,
-                smooth_window,
-                smoothed_name=smoothed_name,
-                **kwargs
-            )
+            self.name,
+            smooth_window,
+            smoothed_name=smoothed_name,
+            **kwargs
+        )
         kwargs['name'] = smoothed_name
         alm_smoothed = Alm(**kwargs)
         self.name = smoothed_name
         return alm_smoothed
 
-
+    def rotate(self, **kwargs):
+        rotated_name = convert.rotate_alm(self.name, **kwargs)
+        self.__dict__.update(kwargs)
+        self.name = rotated_name
+        return self.name
