@@ -15,7 +15,7 @@ class AlmTests(unittest.TestCase, Data.WithTestData):
 
 
     def setUp(self):
-        super().setUp()
+        super(AlmTests, self).setUp()
         self.init_data()
         self.check_exist(self.alm_100_name)
 
