@@ -15,7 +15,7 @@ class PixelMapTests(unittest.TestCase, data.WithTestData):
 
 
     def setUp(self):
-        super().setUp()
+        super(PixelMapTests, self).setUp()
         self.init_data()
 
 
@@ -37,4 +37,4 @@ class PixelMapTests(unittest.TestCase, data.WithTestData):
         pm = pixelmap.gPixelMap(name=self.map_name, **self.attrs)
         ps = pointsource.PointSource(name=self.points_name).to_pixelmap(**self.attrs)
         pm.add_map(ps)
-        self.check_exist(pm.name)
\ No newline at end of file
+        self.check_exist(pm.name)
